@@ -90,10 +90,19 @@ class NaPoleonBinanceFutureBot(object):
     def make_sure_positions_changed(self, positions, sleeping_time = 30):
         position_changed = False
         while not  position_changed:
+            print('updating positions '+positions)
             position_changed = self.change_position(positions)
             # Prints the current time with a five second difference
             time.sleep(sleeping_time)
 
+    def update_position(self, pair, pair_signal):
+        positions ={}
+        if pair == 'BTCUSDT':
+            positions['BTC']=pair_signal
+        else :
+            print('pair not handled for the moment '+pair)
+        self.change_position(positions)
+
 
     def change_position(self, positions):
         usdt_balance, balance, ticker_data, minBTC, minETH, minLTC, minXRP, minEOS, minTRX, minBCH = self.get_balance()
