@@ -85,6 +85,17 @@ class ParallelRunResultAnalyzer():
         signals_df = self.analyzeAllRunSignalsResults(jsonized_output=jsonized_output)
         return results_df, signals_df
 
+    def analyzeHourlyzationResult(self, signal_name_to_analyse, path_to_close_pkl = None, jsonized_output = True, transaction_cost=True):
+        signals_df = self.analyzeAllRunSignalsResults(jsonized_output=jsonized_output)
+        ohlc = pd.read_pickle(path_to_close_pkl)
+        close = ohlc['close']
+        signal = signals_df[signal_name_to_analyse]
+        perf_df = signal_utility.daily_signal_hourlyzation(close,signal,transaction_cost=transaction_cost)
+        results_df = perf_df[[ 'reconstituted_perf']]
+        signals_df = perf_df[['signal']]
+        return results_df, signals_df
+
+
     def analyzeLocalAllRunSignalsResults(self,table_number, jsonized_output = True):
         sqliteConnection = None
         try:
