@@ -376,4 +376,29 @@ def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnov
                 signals_returns_df = freqly_df[['perf_return']].rename(columns={'perf_return': sig})
             else:
                 signals_returns_df[sig] = freqly_df.perf_return
-    return signals_returns_df
\ No newline at end of file
+    return signals_returns_df
+
+def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True):
+    if not isinstance(close, pd.DataFrame):
+        close = pd.DataFrame(close)
+    if not isinstance(daily_signal, pd.DataFrame):
+        daily_signal = pd.DataFrame(daily_signal)
+
+    close = close.pct_change()
+    close.columns = ['close_return']
+    close.fillna(0)
+    daily_signal.columns = ['signal']
+    daily_signal = daily_signal.fillna(0)
+
+    hourly_signal = daily_signal.asfreq(freq='H')
+    hourly_signal.signal = hourly_signal.signal.interpolate(method='linear')
+
+    starting_date = max(hourly_signal.index[0], close.index[0])
+    running_date = min(hourly_signal.index[-1], close.index[-1])
+    close = close.loc[close.index >= starting_date]
+    close = close.loc[close.index <= running_date]
+    hourly_signal = hourly_signal.loc[hourly_signal.index >= starting_date]
+    hourly_signal = hourly_signal.loc[hourly_signal.index <= running_date]
+    perf_df = reconstitute_prediction_perf(y_pred=hourly_signal, y_true=close, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = transaction_cost, print_turnover = False)
+    #new_signals = perf_df[['reconstituted_close', 'reconstituted_perf']]
+    return perf_df
\ No newline at end of file
