@@ -536,6 +536,36 @@ def compute_sharpe(df_ret = None, weights = None, period = 252):
     portfolio = np.cumprod(np.prod(df_ret * weights.values + 1, axis=1))
     return sharpe(portfolio ,period = period), portfolio
 
+def find_best_dd_weights(weights_list, returns_df):
+    N_ = len(weights_list)
+    w0 = np.ones([N_]) / N_
+    const_sum = LinearConstraint(np.ones([1, N_]), [1], [1])
+    up_bound_ = 1.
+    low_bound_ = 0.
+    const_ind = Bounds(low_bound_ * np.ones([N_]), up_bound_ * np.ones([N_]))
+    to_optimize = lambda x: f_dd_weights_mix(weights_list, returns_df, x)
+    w__ = minimize(
+        to_optimize,
+        w0,
+        method='SLSQP',
+        constraints=[const_sum],
+        bounds=const_ind
+    ).x
+    return w__
+
+def f_dd_weights_mix(w_list_, data_, w):
+    np_returns = None
+    counter = 0
+    for weights_ in w_list_:
+        if np_returns is None:
+            np_returns = w[counter] * data_.values * weights_
+        else:
+            np_returns = np_returns + w[counter] * data_.values * weights_
+        counter = counter + 1
+    np_returns = np_returns.sum(axis=1)
+    dds = metrics.drawdown(metrics.from_ret_to_price(np_returns))
+    return dds.max()
+
 
 def f_perf_weights_mix(w_list_, data_, w):
     np_returns = None
@@ -548,9 +578,9 @@ def f_perf_weights_mix(w_list_, data_, w):
         counter = counter + 1
     np_returns = np_returns.sum(axis=1)
     prices = metrics.from_ret_to_price(np_returns)
-    return prices.iloc[-1]
+    return -prices.iloc[-1]
 
-def find_best_perf_weights(returns_df, weights_list):
+def find_best_perf_weights(weights_list, returns_df):
     N_ = len(weights_list)
     w0 = np.ones([N_]) / N_
     const_sum = LinearConstraint(np.ones([1, N_]), [1], [1])
